#!/bin/bash
# Define combos
#SIZES="1 3 8 15 27"
#TOPOS="1 2 4 9 18 36 72 144"

SIZES="8"
TOPOS="4"
NOW=$(date +"%Y-%m-%d")
RESULTS_FILE=results_$NOW
# Write header to result file
echo "# Mesh  Decomp  Time" > $RESULTS_FILE 

# Loop over the combos
for SIZE in $SIZES; do
  for TOPO in $TOPOS; do

    # Exclude certain combinations of variables
    if [ $SIZE == "27" -a $TOPO == "1" ]; then
      continue
    fi
    
    # Copy base directory and enter
    rm -rf ./${SIZE}M_${TOPO}N
    cp -r cavity_parallel ./${SIZE}M_${TOPO}N
    cd ${SIZE}M_${TOPO}N
    
    # Copy the right input files
    cp constant/polyMesh/blockMeshDict.${SIZE}M constant/polyMesh/blockMeshDict
    cp system/decomposeParDict.${TOPO}N system/decomposeParDict

    # Create mesh
    
    # Write config info to file
    echo "export SIZE=$SIZE" > config
    echo "export TOPO=$TOPO" >> config
    echo "export RESULTS_FILE=$RESULTS_FILE" >> config
    
    # Submit job
    WALLTIME=15
    #echo "WALLTIME=" $WALLTIME
    QSUBARGS="-l nodes=$TOPO:ppn=16 -l walltime=00:$WALLTIME:00 -N ${USER}_${SIZE}_${TOPO} -o OB_${SIZE}M_${TOPO}N_OUT -j oe"
    echo -n $QSUBARGS > qsubargs    
    qsub $QSUBARGS Job.sh

    # Return to base dir
    cd ..
  done
  USERNAME=`id -nu` 
  qstat -u $USERNAME >queue_info_$USERNAME
done
